package ch.sws.tasaf.bo;

import java.util.ArrayList;
import org.apache.log4j.Logger;
import ch.sws.tasaf.bo.vo.*;
import ch.sws.tasaf.db.AreaDAO;
import ch.sws.tasaf.db.DestinationDAO;
import ch.sws.tasaf.util.ClientLogInit;

/**
 * Control-Klasse fr die Business-Logic.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class Control
{
  // Logging
  private static final Logger LOG = Logger.getLogger( Control.class );
  private TravelAssembler travelAssembler = null;

  /** Diese Methode wird einmal und noch vor dem Classloader ausgefhrt.
   *  Logging wird inizialisiert
   */
  static
  {
    ClientLogInit.initLogging();
  }

  /** Konstruktor - Singleton. */
  public Control()
  {
    travelAssembler = new TravelAssembler( );
  }

  /**
   * Initialisierung BookingVO
   */
  public void init()
  {
    travelAssembler = new TravelAssembler( );
  }

  /**
   * Gibt das Menu als ArrayListe zurck
   * @throws Exception
   * @return ArrayList
   */
  public ArrayList getMenu() throws Exception
  {
    AreaDAO areaDAO = new AreaDAO();
    return areaDAO.select();
  }

  /**
   * Gibt ein Destination-Value-Objekt zurck
   * @param idDestination int
   * @throws Exception Unerwarteter Fehler
   * @return DestinationVO
   */
  public DestinationVO getDestination( int idDestination ) throws Exception
  {
    DestinationDAO destinationDAO = new DestinationDAO();
    return destinationDAO.select( idDestination );
  }

  /**
   * Gibt ein Booking-Value-Objekt zurck
   * @throws Exception Unerwarteter Fehler
   * @return BookingVO
   */
  public BookingVO getVorschau() throws Exception
  {
    return travelAssembler.getBookingVO();
  }

  /**
   * bergibt ein Booking-Value-Objekt
   * @param bookingVO BookingVO
   * @throws Exception Unerwarteter Fehler
   */
  public String saveVorschau( BookingVO bookingVO ) throws Exception
  {
    return travelAssembler.saveBooking( bookingVO );
  }

  /**
   * Gibt eine ArrayListe der Teilnehmer zurck, nachdem ein weiterer
   * Teilnehmer hinzugefgt wurde
   * @param participantVO ParticipantVO
   * @return ArrayList
   */
  public ArrayList addTN( ParticipantVO participantVO )
  {
    return travelAssembler.addTN( participantVO );
  }

  /**
   * Gibt eine aktualisierte ArrayListe der Teilnehmer zurck,
   * nachdem ein Teilnehmer gelscht wurde
   * @param index int
   * @throws Exception
   * @return ArrayList
   */
  public ArrayList removeTN( int index ) throws Exception
  {
    return travelAssembler.removeTN( index );
  }

  /**
   * Gibt eine ArrayListe der Programme zurck, nachdem ein weiteres
   * Programm hinzugefgt wurde
   * @param programVO ProgramVO
   * @return ArrayList
   */
  public ArrayList addProgram( ProgramVO programVO )
  {
    return travelAssembler.addProgram( programVO );
  }

  /**
   * Gibt eine aktualisierte ArrayListe der Programme zurck,
   * nachdem ein Programm gelscht wurde
   * @param index int
   * @throws Exception
   * @return ArrayList
   */
  public ArrayList removeProgram( int index ) throws Exception
  {
    return travelAssembler.removeProgram( index );
  }

  /**
   * Gibt eine aktualisierte ArrayListe zurck, nachdem die
   * Indexe aktualisiert wurden
   * @param programs ArrayList
   * @return ArrayList
   */
  public ArrayList sortPrograms( ArrayList programs )
  {
    return travelAssembler.sortPrograms( programs );
  }

  /**
   * Gibt eine aktualisierte ArrayListe zurck, nachdem neue
   * Daten eingefgt wurden
   * @param programsUpdate ArrayList
   * @return ArrayList
   */
  public ArrayList updatePrograms( ArrayList programsUpdate )
  {
    return travelAssembler.updatePrograms( programsUpdate );
  }

  /**
   * Gibt eine ArrayListe mit den TransportArten zurck
   * @throws Exception Unerwarteter Fehler
   * @return ArrayList
   */
  public ArrayList getTransportArten() throws Exception
  {
    return travelAssembler.getTransportArten();
  }

  /**
   * Fgt die ausgewhlten Transportarten in das Booking-Value-Objekt ein
   * @param transports ArrayList
   * @throws Exception Unerwarteter Fehler
   */
  public void addTransports( ArrayList transports ) throws Exception
  {
    travelAssembler.addTransports( transports );
  }

  /**
   * Fgt das Person-Value-Objekt in das Booking-Value-Objekt ein
   * @param personVO PersonVO
   */
  public void addPerson( PersonVO personVO )
  {
    travelAssembler.addPerson( personVO );
  }

  /**
   * Fgt das Travel-Value-Objekt in das Booking-Value-Objekt ein
   * @param travelVO TravelVO
   */
  public void addTravel( TravelVO travelVO )
  {
    travelAssembler.addTravel( travelVO );
  }

  /**
   * Gibt eine ArrayListe mit den Countries zurck
   * @throws Exception Unerwarteter Fehler
   * @return ArrayList
   */
  public ArrayList getCountry() throws Exception
  {
    return travelAssembler.getCountry();
  }

  /**
   * Gibt eine ArrayListe von Hotel-Value-Objekten zurck
   * @throws Exception Unerwarteter Fehler
   * @return ArrayList
   */
  public ArrayList getHotel()
  {
    return null;
  }
}
