package ch.sws.tasaf.bo.vo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * BookingVO: ValueObject fr die Buchung. Im BookingVO werden alle Value-Objects fr die Buchung
 * zusammengefasst. Somit ist das BookingVO das Master-Value-Object.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class BookingVO implements Serializable
{
  private TravelVO travelVO;
  private PersonVO personVO;
  private ArrayList programs;
  private ArrayList participants;
  private ArrayList transports;
  private int anzahlTN;

  /**
   * Standard-Konstruktor
   */
  public BookingVO()
  {
    travelVO = new TravelVO();
    personVO = new PersonVO();
    programs = new ArrayList();
    participants = new ArrayList();
    transports = new ArrayList();

    anzahlTN = 0;
  }

  /*******************************************************************************************************************
     G E T T E R - M E T H O D E N
   *******************************************************************************************************************/

  /**
   * Gibt den Wert zurck
   * @return TravelVO travelVO
   */
  public TravelVO getTravelVO()
  {
    return travelVO;
  }

  /**
   * Gibt den Wert zurck
   * @return PersonVO personVO
   */
  public PersonVO getPersonVO()
  {
    return personVO;
  }

  /**
   * Gibt den Wert zurck
   * @return ArrayList programs
   */
  public ArrayList getPrograms()
  {
    return programs;
  }

  /**
   * Gibt den Wert zurck
   * @return ArrayList participants
   */
  public ArrayList getParticipants()
  {
    return participants;
  }

  /**
   * Gibt den Wert zurck
   * @return ArrayList transports
   */
  public ArrayList getTransports()
  {
    return transports;
  }

  /**
   * Gibt den Wert zurck
   * @return int anzahlTN
   */
  public int getAnzahlTN()
  {
    return anzahlTN;
  }

  /*******************************************************************************************************************
    S E T T E R - M E T H O D E N
   *******************************************************************************************************************/

  /**
   * Setzt den bergebenen Wert
   * @param travelVO TravelVO
   */
  public void setTravelVO( TravelVO travelVO )
  {
    this.travelVO = travelVO;
  }

  /**
   * Setzt den bergebenen Wert
   * @param personVO PersonVO
   */
  public void setPersonVO( PersonVO personVO )
  {
    this.personVO = personVO;
  }

  /**
   * Setzt den bergebenen Wert
   * @param programs ArrayList
   */
  public void setPrograms( ArrayList programs )
  {
    this.programs = programs;
  }

  /**
   * Setzt den bergebenen Wert
   * @param participants ArrayList
   */
  public void setParticipants( ArrayList participants )
  {
    this.participants = participants;
  }

  /**
   * Setzt den bergebenen Wert
   * @param transports ArrayList
   */
  public void setTransports( ArrayList transports )
  {
    this.transports = transports;
  }

  /**
   * Setzt den bergebenen Wert
   * @param anzahlTN int
   */
  public void setAnzahlTN( int anzahlTN )
  {
    this.anzahlTN = anzahlTN;
  }

  /**
   * Die toString()-Methode gibt alle Attribute als String zurck.
   * @return buf String mit allen Attributen
   */
  public String toString()
  {
    Iterator iter;
    StringBuffer buf = new StringBuffer();
    buf.append( " travelVO = <" + this.travelVO.toString() + "> \n" );
    buf.append( " personVO = <" + this.personVO.toString() + "> \n" );
    iter = programs.iterator();
    while ( iter.hasNext() )
    {
      buf.append( iter.next().toString() );
    }
    iter = participants.iterator();
    while ( iter.hasNext() )
    {
      buf.append( iter.next().toString() );
    }
    iter = transports.iterator();
    while ( iter.hasNext() )
    {
      buf.append( iter.next().toString() );
    }
    buf.append( " anzahlTN = <" + String.valueOf( this.anzahlTN ) + "> \n" );
    return buf.toString();
  }
}
