package ch.sws.tasaf.client;

import java.util.ArrayList;
import ch.sws.tasaf.bo.Control;
import ch.sws.tasaf.bo.vo.*;

/**
 * Die Klasse Delegate delegiert alle Anfragen an die Klasse Control der Business-Logik.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class Delegate
{
  private static Delegate delegate = null; // stat. Feld fr Singleton
  private Control control = null;

  /** Konstruktor - Singleton. */
  private Delegate()
  {
    control = new Control();
  }

  /**
   * statische Methode, die eine Referenz auf das Delegate
   * zurckgibt. Hier ist das Singleton-Pattern implementiert.
   * @return Referenz auf Delegate (= me)
   */
  public static Delegate getInstance()
  {
    if ( delegate == null )
    {
      delegate = new Delegate();
    }
    return delegate;
  }

  /**
   * Initialisierung BookingVO
   */
  public void init()
  {
    control.init();
  }

  /**
   * Gibt das Menu als ArrayListe zurck
   * @throws Exception
   * @return ArrayList
   */
  public ArrayList getMenu() throws Exception
  {
    return control.getMenu();
  }

  /**
   * Gibt ein Destination-Value-Objekt zurck
   * @param idDestination int
   * @throws Exception Unerwarteter Fehler
   * @return DestinationVO
   */
  public DestinationVO getDestination( int idDestination ) throws Exception
  {
    return control.getDestination( idDestination );
  }

  /**
   * Gibt ein Booking-Value-Objekt zurck
   * @throws Exception Unerwarteter Fehler
   * @return BookingVO
   */
  public BookingVO getVorschau() throws Exception
  {
    return control.getVorschau();
  }

  /**
   * bergibt ein Booking-Value-Objekt
   * @param bookingVO BookingVO
   * @throws Exception Unerwarteter Fehler
   */
  public void saveVorschau( BookingVO bookingVO ) throws Exception
  {
    control.saveVorschau( bookingVO );
  }

  /**
   * Gibt eine ArrayListe der Teilnehmer zurck, nachdem ein weiterer
   * Teilnehmer hinzugefgt wurde
   * @param participantVO ParticipantVO
   * @return ArrayList
   */
  public ArrayList addTN( ParticipantVO participantVO )
  {
    return control.addTN( participantVO );
  }

  /**
   * Gibt eine aktualisierte ArrayListe der Teilnehmer zurck,
   * nachdem ein Teilnehmer gelscht wurde
   * @param index int
   * @throws Exception
   * @return ArrayList
   */
  public ArrayList removeTN( int index ) throws Exception
  {
    return control.removeTN( index );
  }

  /**
   * Gibt eine ArrayListe der Programme zurck, nachdem ein weiteres
   * Programm hinzugefgt wurde
   * @param programVO ProgramVO
   * @return ArrayList
   */
  public ArrayList addProgram( ProgramVO programVO )
  {
    return control.addProgram( programVO );
  }

  /**
   * Gibt eine aktualisierte ArrayListe der Programme zurck,
   * nachdem ein Programm gelscht wurde
   * @param index int
   * @throws Exception
   * @return ArrayList
   */
  public ArrayList removeProgram( int index ) throws Exception
  {
    return control.removeProgram( index );
  }

  /**
   * Gibt eine aktualisierte ArrayListe zurck, nachdem die
   * Indexe aktualisiert wurden
   * @param programs ArrayList
   * @return ArrayList
   */
  public ArrayList sortPrograms( ArrayList programs )
  {
    return control.sortPrograms( programs );
  }

  /**
   * Gibt eine aktualisierte ArrayListe zurck, nachdem neue
   * Daten eingefgt wurden
   * @param programsUpdate ArrayList
   * @return ArrayList
   */
  public ArrayList updatePrograms( ArrayList programsUpdate )
  {
    return control.updatePrograms( programsUpdate );
  }

  /**
   * Gibt eine ArrayListe mit den TransportArten zurck
   * @throws Exception Unerwarteter Fehler
   * @return ArrayList
   */
  public ArrayList getTransportArten() throws Exception
  {
    return control.getTransportArten();
  }

  /**
   * Fgt die ausgewhlten Transportarten in das Booking-Value-Objekt ein
   * @param transports ArrayList
   * @throws Exception Unerwarteter Fehler
   */
  public void addTransports( ArrayList transports ) throws Exception
  {
    control.addTransports( transports );
  }

  /**
   * Fgt das Person-Value-Objekt in das Booking-Value-Objekt ein
   * @param personVO PersonVO
   */
  public void addPerson( PersonVO personVO )
  {
    control.addPerson( personVO );
  }

  /**
   * Fgt das Travel-Value-Objekt in das Booking-Value-Objekt ein
   * @param travelVO TravelVO
   */
  public void addTravel( TravelVO travelVO )
  {
    control.addTravel( travelVO );
  }

  /**
   * Gibt eine ArrayListe mit den Countries zurck
   * @throws Exception Unerwarteter Fehler
   * @return ArrayList
   */
  public ArrayList getCountry() throws Exception
  {
    return control.getCountry();
  }

  /**
   * Gibt eine ArrayListe von Hotel-Value-Objekten zurck
   * @throws Exception Unerwarteter Fehler
   * @return ArrayList
   */
  public ArrayList getHotel()
  {
    return control.getHotel();
  }
}
