package ch.sws.tasaf.client;

import java.util.ArrayList;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import org.apache.struts.action.*;

/**
 * Die Klasse MenuAction holt die Daten fuer die Menu-Anzeige
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class MenuAction extends Action
{
  private static final Logger LOG = Logger.getLogger( MenuAction.class );

  /**
   * Die Methode execute wird beim Applikationsstart aufgerufen.
   * Durch diese Methode wird die nchste Seite aufgerufen die im Client angezeigt wird.
   * In der Methode werden die Menu-Daten von der Datenbank geholt und in der Session gespeichert
   *
   * @param actionMapping ActionMapping
   * @param actionForm ActionForm
   * @param httpServletRequest HttpServletRequest
   * @param httpServletResponse HttpServletResponse
   * @return ActionForward
   */
  public ActionForward execute( ActionMapping actionMapping,
                                ActionForm actionForm,
                                HttpServletRequest httpServletRequest,
                                HttpServletResponse httpServletResponse )
  {
    ActionErrors errors = new ActionErrors();
    ArrayList alAreaVO = null;

    // Session erstellen
    HttpSession session = httpServletRequest.getSession( true );
    LOG.info("Session Id: " + session.getId());
    LOG.info("Session isNew: " + session.isNew());
    LOG.info("Session CreationTime: " + new java.util.Date( session.getCreationTime()) );
    LOG.info("Session MaxInactiveInterval: " + session.getMaxInactiveInterval());

    try
    {
      Delegate.getInstance().init();
      alAreaVO = Delegate.getInstance().getMenu();
    }
    catch ( Exception ex )
    {
      LOG.debug( "MenuAction: " + ex.getMessage() );
      errors.add( "getMenu", new ActionError( "errors.loadDataError", ex.getMessage() ) );
      saveErrors( httpServletRequest, errors );
      return ( new ActionForward( actionMapping.getInput() ) );
    }

    // Daten die im Menu angezeigt werden auf Session speichern
    session.setAttribute( "alAreaVO", alAreaVO );

    return actionMapping.findForward( "home" );
  }
}
