package ch.sws.tasaf.client;

import java.text.SimpleDateFormat;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import org.apache.struts.action.*;
import org.apache.struts.util.MessageResources;
import ch.sws.tasaf.bo.vo.BookingVO;
import ch.sws.tasaf.bo.vo.PersonVO;

/**
 * Die Klasse OrganisatorAction verarbeitet die Daten der OrganisatorForm.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @see OrganisatorForm
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class OrganisatorAction extends Action
{
  private static final Logger LOG = Logger.getLogger( OrganisatorAction.class );

  /**
   * Die Methode execute wird aufgerufen, wenn auf der JavaServerPage der Button "Weiter" gedrckt wird.
   * Durch diese Methode wird die nchste Seite aufgerufen die im Client angezeigt wird.
   * In der Methode werden die Daten verarbeitet die in der Form gehalten werden.
   * @param actionMapping ActionMapping
   * @param actionForm ActionForm
   * @param httpServletRequest HttpServletRequest
   * @param httpServletResponse HttpServletResponse
   * @throws Exception
   * @return ActionForward
   */
  public ActionForward execute( ActionMapping actionMapping, ActionForm actionForm, HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse ) throws Exception
  {
    ActionErrors errors = new ActionErrors();
    MessageResources messages = getResources( httpServletRequest );
    OrganisatorForm organisatorForm = ( OrganisatorForm ) actionForm;
    HttpSession session = httpServletRequest.getSession();

    PersonVO personVO = null;

    try
    {
      personVO = fillPersonVO( organisatorForm );
    }
    catch ( Exception ex )
    {
      LOG.debug( "Exception (fillPersonVO):" + ex.getMessage() );
      errors.add( "personVO", new ActionError( "errors.validateError", ex.getMessage() ) );
      saveErrors( httpServletRequest, errors );
      return ( new ActionForward( actionMapping.getInput() ) );
    }

    // Aufruf des Delegate
    Delegate delegate = Delegate.getInstance();
    delegate.addPerson( personVO );

    BookingVO bookingVO = delegate.getVorschau();
    session.setAttribute( "bookingVO", bookingVO );

    return ( actionMapping.findForward( "forward" ) );
  }

  /**
   * Diese Methode fllt das PersonenVO ab.
   * @param organisatorForm OrganisatorForm
   * @throws Exception Unerwarteter Fehler
   * @return PersonVO Value-Object
   */
  private PersonVO fillPersonVO( OrganisatorForm organisatorForm ) throws Exception
  {
    PersonVO personVO = new PersonVO();
    SimpleDateFormat df = new SimpleDateFormat( "dd.MM.yyyy" );

    personVO.setFirstname( organisatorForm.getTxfName() );
    personVO.setLastname( organisatorForm.getTxfVorname() );
    personVO.setAddress( organisatorForm.getTxfStrasse() );
    personVO.setZipCode( Integer.parseInt( organisatorForm.getTxfPlz() ) );
    personVO.setCity( organisatorForm.getTxfOrt() );
    personVO.setCountryCd( organisatorForm.getCbxLand() );
    personVO.setEmail( organisatorForm.getTxfEmail() );
    personVO.setCcType( organisatorForm.getCbxCartFirm() );
    personVO.setCcNumber( organisatorForm.getTxfCartNr() );
    personVO.setCcName( organisatorForm.getTxfCartName() );
    // Datum zusammensetzen fr ExpiryDate
    String date = "01." + organisatorForm.getTxfCartMonat() + "." + organisatorForm.getTxfCartJahr();
    personVO.setCcExpiryDate( new java.sql.Date( df.parse( date ).getTime() ) );

    return personVO;
  }
}
