package ch.sws.tasaf.client;

import java.text.SimpleDateFormat;
import java.util.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import org.apache.struts.action.*;
import org.apache.struts.actions.LookupDispatchAction;
import ch.sws.tasaf.bo.vo.ProgramVO;

/**
 * Die Klasse ProgramAction verarbeitet die Daten der ProgramForm.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @see ProgramForm
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class ProgramAction extends LookupDispatchAction
{
  private static final Logger LOG = Logger.getLogger( ProgramAction.class );

  private int counter = 0;
  private HttpSession session;
  private Delegate delegate;
  private ArrayList programs;
  private ProgramForm programForm;
  private ProgramVO programVO;
  private ActionErrors errors;
  private HttpServletRequest request;
  ActionMapping actionMapping;

  /**
   * getKeyMethodMap
   * @return Map
   */
  protected Map getKeyMethodMap()
  {
    Map map = new HashMap();
    map.put( "button.refresh", "setRefresh" );
    map.put( "button.weiter", "getNextSite" );
    return map;
  }

  /**
   * Die Methode setRefresh aktualisiert die Daten auf der Form.
   */
  public ActionForward setRefresh( ActionMapping actionMapping, ActionForm actionForm, HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse )
  {
    errors = new ActionErrors();
    programForm = ( ProgramForm ) actionForm;
    session = httpServletRequest.getSession();
    request = httpServletRequest;
    this.actionMapping = actionMapping;

    delegate = Delegate.getInstance();

    // Programs-ArrayListe aus Session holen
    programs = ( ArrayList ) session.getAttribute( "programs" );
    if ( programs == null )
    {
      counter = 0;
    }
    else
    {
      counter = programs.size() + 1;
    }

    // Sortierte ArrayList mit dem korrekten Index
    programs = delegate.sortPrograms( programs );

    // Prfen ob ein Program selektiert ist und aus der ArrayListe gelscht werden muss
    if ( programForm.getSelectedOptions() != null )
    {
      try
      {
        programs = removeProgram();

        if(programs == null)
        {
          programForm.reset( actionMapping, httpServletRequest );
        }
        else
        {
          session.setAttribute( "programs", programs );
        }
      }
      catch ( Exception ex )
      {
        LOG.debug( "Exception (removeProgram):" + ex.getMessage() );
        errors.add( "removeProgram", new ActionError( "errors.removeError", ex.getMessage() ) );
        saveErrors( httpServletRequest, errors );
        return ( new ActionForward( actionMapping.getInput() ) );
      }
    }

    if ( programs != null )
    {
      try
      {
        // Werte in Programs abfllen und in BookingVO zurckschreiben.
        programs = delegate.updatePrograms( addAttributs() );
      }
      catch ( Exception ex )
      {
        LOG.debug( "Exception (updatePrograms):" + ex.getMessage() );
        errors.add( "updatePrograms", new ActionError( "errors.updateError", ex.getMessage() ) );
        saveErrors( httpServletRequest, errors );
        return ( new ActionForward( actionMapping.getInput() ) );
      }
    }
    // Werte in Form zurckschreiben
    session.setAttribute( "programs", programs );
    return ( actionMapping.findForward( "self" ) );
  }

  /**
   * Die Methode getNextSite verarbeitet die Daten aus der Form und ruft die nchste Seite auf.
   */
  public ActionForward getNextSite( ActionMapping actionMapping, ActionForm actionForm, HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse )
  {
    errors = new ActionErrors();
    programForm = ( ProgramForm ) actionForm;
    session = httpServletRequest.getSession();
    request = httpServletRequest;
    this.actionMapping = actionMapping;

    delegate = Delegate.getInstance();

    // Programs-ArrayListe aus Session holen
    programs = ( ArrayList ) session.getAttribute( "programs" );
    if ( programs == null )
    {
      counter = 0;
    }
    else
    {
      counter = programs.size() + 1;
    }

    // Sortierte ArrayList mit dem korrekten Index
    programs = delegate.sortPrograms( programs );

    // Prfen ob ein Program selektiert ist und aus der ArrayListe gelscht werden muss
    if ( programForm.getSelectedOptions() != null )
    {
      try
      {
        programs = removeProgram();

        if(programs == null)
        {
          programForm.reset( actionMapping, httpServletRequest );
        }
        else
        {
          session.setAttribute( "programs", programs );
        }
      }
      catch ( Exception ex )
      {
        LOG.debug( "Exception (removeProgram):" + ex.getMessage() );
        errors.add( "removeProgram", new ActionError( "errors.removeError", ex.getMessage() ) );
        saveErrors( httpServletRequest, errors );
        return ( new ActionForward( actionMapping.getInput() ) );
      }
    }

    if ( programs != null )
    {
      try
      {
        /** @todo Validieren ob eine Eingabe leer ist !!! */
        // Werte in Programs abfllen und in BookingVO zurckschreiben.
        programs = delegate.updatePrograms( addAttributs() );
      }
      catch ( Exception ex )
      {
        LOG.debug( "Exception (updatePrograms):" + ex.getMessage() );
        errors.add( "updatePrograms", new ActionError( "errors.updateError", ex.getMessage() ) );
        saveErrors( httpServletRequest, errors );
        return ( new ActionForward( actionMapping.getInput() ) );
      }
    }
    // Werte in Form zurckschreiben
    session.setAttribute( "programs", programs );

    try
    {
      // Fgt die Transportarten in die Session
      ArrayList transportArtList = delegate.getTransportArten();
      session.setAttribute( "transportArtList", transportArtList );
    }
    catch ( Exception ex )
    {
      LOG.debug( "Exception (transportArtList):" + ex.getMessage() );
      errors.add( "transportArtList", new ActionError( "errors.loadDataError", ex.getMessage() ) );
      saveErrors( httpServletRequest, errors );
      return ( new ActionForward( actionMapping.getInput() ) );
    }

    return ( actionMapping.findForward( "forward" ) );
  }

  /**
   * Diese Methode fgt die Werte aus der Form in die ProgramVO ab
   * @throws Exception
   * @return ArrayList
   */
  private ArrayList addAttributs() throws Exception
  {
    ArrayList list = new ArrayList();
    SimpleDateFormat df = new SimpleDateFormat( "dd.MM.yyyy" );

    String[] idVon = programForm.getTxfVon();
    String[] idBis = programForm.getTxfBis();
    String[] idEz = programForm.getTxfEz();
    String[] idDz = programForm.getTxfDz();

    Iterator iter = programs.iterator();
    int index = 0;
    while ( iter.hasNext() )
    {
      ProgramVO programVO = ( ProgramVO ) iter.next();
      LOG.debug("DATUM aus Array: " + idVon[ index ] );
      Date fromDate = df.parse( idVon[ index ] );
      Date toDate = df.parse( idBis[ index ] );
      int anzEz = Integer.parseInt( idEz[ index ] );
      int anzDz = Integer.parseInt( idDz[ index ] );
      LOG.debug("DATUM nach parsing: " + fromDate );
      programVO.setFromDate( new java.sql.Date( fromDate.getTime() ) );
      programVO.setToDate( new java.sql.Date( toDate.getTime() ) );
      programVO.setNumberOfSingleRoom( anzEz );
      programVO.setNumberOfDoubleRoom( anzDz );
      programVO.setCosts( getCosts( anzEz, anzDz, programVO.getHotelVO().getPriceSingleRoom(), programVO.getHotelVO().getPriceDoubleRoom() ) );
      list.add( programVO );
      index++;
    }
    return list;
  }

  /**
   * Berechnet die Gesamtkosten des Hotels
   * @param anzEz int
   * @param anzDz int
   * @param priceSingleRoom float
   * @param priceDoubleRoom float
   * @return float costs
   */
  private float getCosts( int anzEz, int anzDz, float priceSingleRoom, float priceDoubleRoom )
  {
    return ( ( anzEz * priceSingleRoom ) + ( anzDz * priceDoubleRoom ) );
  }

  /**
   * Diese Methode lscht einen Program aus der ArrayListe
   */
  private ArrayList removeProgram() throws Exception
  {
    int[] idRemove = programForm.getSelectedOptions();
    for ( int i = idRemove.length - 1; i >= 0; i-- )
    {
      int id = idRemove[ i ];
      programs = delegate.removeProgram( id );
    }
    // Counter aktualisieren
    if ( programs == null )
    {
      counter = 0;
    }
    else
    {
      counter = programs.size() + 1;
    }
    return programs;
  }
}
