package ch.sws.tasaf.client;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import org.apache.struts.action.*;
import ch.sws.tasaf.bo.vo.TravelTransportVO;
import ch.sws.tasaf.bo.vo.TravelVO;

/**
 * Die Klasse ReisedatenAction verarbeitet die Daten der ReisedatenForm.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @see ReisedatenForm
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class ReisedatenAction extends Action
{
  private static final Logger LOG = Logger.getLogger( ReisedatenAction.class );

  /**
   * Die Methode execute wird aufgerufen, wenn auf der JavaServerPage der Button "Weiter" gedrckt wird.
   * Durch diese Methode wird die nchste Seite aufgerufen die im Client angezeigt wird.
   * In der Methode werden die Daten verarbeitet die in der Form gehalten werden.
   * @param actionMapping ActionMapping
   * @param actionForm ActionForm
   * @param httpServletRequest HttpServletRequest
   * @param httpServletResponse HttpServletResponse
   * @throws Exception
   * @return ActionForward
   */
  public ActionForward execute( ActionMapping actionMapping, ActionForm actionForm, HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse )
  {
    ActionErrors errors = new ActionErrors();
    ReisedatenForm reisedatenForm = ( ReisedatenForm ) actionForm;
    HttpSession session = httpServletRequest.getSession();

    TravelVO travelVO = null;
    ArrayList transports = new ArrayList();

    try
    {
      travelVO = fillTravelVO( reisedatenForm );

      int[] idTransport = reisedatenForm.getSelectedOptions();
      for ( int i = 0; i < idTransport.length; i++ )
      {
        int id = idTransport[ i ];
        transports.add( fillTravelTransportVO( 0, id ) );
      }
    }
    catch ( Exception ex )
    {
      LOG.debug( "Exception (travelVO):" + ex.getMessage() );
      errors.add( "travelVO", new ActionError( "errors.validateError", ex.getMessage() ) );
      saveErrors( httpServletRequest, errors );
      return ( new ActionForward( actionMapping.getInput() ) );
    }

    // Aufruf des Delegate
    Delegate delegate = Delegate.getInstance();
    delegate.addTravel( travelVO );
    try
    {
      delegate.addTransports( transports );
    }
    catch ( Exception ex )
    {
      LOG.debug( "Exception (addTransports):" + ex.getMessage() );
      errors.add( "addTransports", new ActionError( "errors.insertError", ex.getMessage() ) );
      saveErrors( httpServletRequest, errors );
      return ( new ActionForward( actionMapping.getInput() ) );
    }

    try
    {
      // Fgt die Country-Werte in die Session
      ArrayList countryList = delegate.getCountry();
      session.setAttribute( "countryList", countryList );
    }
    catch ( Exception ex )
    {
      LOG.debug( "Exception (countryList):" + ex.getMessage() );
      errors.add( "countryList", new ActionError( "errors.loadDataError", ex.getMessage() ) );
      saveErrors( httpServletRequest, errors );
      return ( new ActionForward( actionMapping.getInput() ) );
    }

    return ( actionMapping.findForward( "forward" ) );
  }

  /**
   * Diese Methode fllt das TravelVO ab.
   * @param reisedatenForm ReisedatenForm
   * @throws Exception Unerwarteter Fehler
   * @return TravelVO Value-Object
   */
  private TravelVO fillTravelVO( ReisedatenForm reisedatenForm ) throws ParseException
  {
    TravelVO travelVO = new TravelVO();
    SimpleDateFormat df = new SimpleDateFormat( "dd.MM.yyyy" );

    travelVO.setStartCity( reisedatenForm.getTxfAusgangsort() );

    java.util.Date startDate = df.parse( reisedatenForm.getTxfStartDate() );
    travelVO.setStartDate( new java.sql.Date( startDate.getTime() ) );

    java.util.Date endDate = df.parse( reisedatenForm.getTxfEndDate() );
    travelVO.setEndDate( new java.sql.Date( endDate.getTime() ) );

    return travelVO;
  }

  /**
   * Diese Methode fllt das TravelVO ab.
   * @param reisedatenForm ReisedatenForm
   * @throws Exception Unerwarteter Fehler
   * @return TravelVO Value-Object
   */
  private TravelTransportVO fillTravelTransportVO( int idTravel, int idTransport ) throws Exception
  {
    TravelTransportVO travelTransportVO = new TravelTransportVO();
    travelTransportVO.setTransportId( idTransport );
    travelTransportVO.setTravelId( idTravel );
    return travelTransportVO;
  }
}
