package ch.sws.tasaf.client;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import org.apache.struts.action.*;
import org.apache.struts.actions.LookupDispatchAction;
import ch.sws.tasaf.bo.vo.ParticipantVO;

/**
 * Die Klasse TeilnehmerAction verarbeitet die Daten der TeilnehmerForm.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @see TeilnehmerForm
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class TeilnehmerAction extends LookupDispatchAction
{
  private static final Logger LOG = Logger.getLogger( TeilnehmerAction.class );

  private int counter = 0;
  private HttpSession session;
  private Delegate delegate;
  private ArrayList participants;
  private TeilnehmerForm teilnehmerForm;
  private ParticipantVO participantVO;
  private ActionErrors errors;

  /**
   * getKeyMethodMap
   * @return Map
   */
  protected Map getKeyMethodMap()
  {
    Map map = new HashMap();
    map.put( "button.refresh", "setRefresh" );
    map.put( "button.weiter", "getNextSite" );
    return map;
  }

  /**
   * Die Methode setRefresh aktualisiert die Daten auf der Form.
   */
  public ActionForward setRefresh( ActionMapping actionMapping, ActionForm actionForm, HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse )
  {
    errors = new ActionErrors();
    teilnehmerForm = ( TeilnehmerForm ) actionForm;
    session = httpServletRequest.getSession();

    participants = new ArrayList();
    delegate = Delegate.getInstance();

    if ( ( teilnehmerForm.getTxfName().equals( "" ) ) | ( teilnehmerForm.getTxfVorname().equals( "" ) ) | ( teilnehmerForm.getTxfOrt().equals( "" ) ) )
    {
      // Prfen ob ein selektierte Teilnehmer aus der ArrayListe gelscht werden muss
      if ( teilnehmerForm.getSelectedOptions() != null )
      {
        try
        {
          participants = removeTN();
          session.setAttribute( "participants", participants );
        }
        catch ( Exception ex )
        {
          LOG.debug( "Exception (removeTN):" + ex.getMessage() );
          errors.add( "removeTN", new ActionError( "errors.removeError", ex.getMessage() ) );
          saveErrors( httpServletRequest, errors );
          return ( new ActionForward( actionMapping.getInput() ) );
        }
      }
      // nichts machen
      return ( actionMapping.findForward( "self" ) );
    }
    else
    {
      try
      {
        addTN();
      }
      catch ( Exception ex )
      {
        LOG.debug( "Fehler:" + ex.getMessage() );
        errors.add( "participantVO", new ActionError( "errors.insertError", ex.getMessage() ) );
        saveErrors( httpServletRequest, errors );
        return ( new ActionForward( actionMapping.getInput() ) );
      }

      // Prfen ob ein selektierte Teilnehmer aus der ArrayListe gelscht werden muss
      if ( teilnehmerForm.getSelectedOptions() != null )
      {
        try
        {
          participants = removeTN();
        }
        catch ( Exception ex )
        {
          LOG.debug( "Exception (removeTN):" + ex.getMessage() );
          errors.add( "removeTN", new ActionError( "errors.removeError", ex.getMessage() ) );
          saveErrors( httpServletRequest, errors );
          return ( new ActionForward( actionMapping.getInput() ) );
        }
      }

      session.setAttribute( "participants", participants );
      teilnehmerForm.reset( actionMapping, httpServletRequest );

      return ( actionMapping.findForward( "self" ) );
    }
  }

  /**
   * Die Methode getNextSite verarbeitet die Daten aus der Form und ruft die nchste Seite auf.
   */
  public ActionForward getNextSite( ActionMapping actionMapping, ActionForm actionForm, HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse )
  {
    errors = new ActionErrors();
    teilnehmerForm = ( TeilnehmerForm ) actionForm;
    session = httpServletRequest.getSession();

    participants = new ArrayList();
    delegate = Delegate.getInstance();

    if ( ( teilnehmerForm.getTxfName().equals( "" ) ) | ( teilnehmerForm.getTxfVorname().equals( "" ) ) | ( teilnehmerForm.getTxfOrt().equals( "" ) ) )
    {
      // Prfen ob ein selektierte Teilnehmer aus der ArrayListe gelscht werden muss
      if ( teilnehmerForm.getSelectedOptions() != null )
      {
        try
        {
          participants = removeTN();
          session.setAttribute( "participants", participants );
        }
        catch ( Exception ex )
        {
          LOG.debug( "Exception (removeTN):" + ex.getMessage() );
          errors.add( "addTN", new ActionError( "errors.removeError", ex.getMessage() ) );
          saveErrors( httpServletRequest, errors );
          return ( new ActionForward( actionMapping.getInput() ) );
        }
      }
      // nichts machen
      return ( actionMapping.findForward( "forward" ) );
    }
    else
    {
      try
      {
        addTN();
      }
      catch ( Exception ex )
      {
        LOG.debug( "Exception (addTN):" + ex.getMessage() );
        errors.add( "addTN", new ActionError( "errors.insertError", ex.getMessage() ) );
        saveErrors( httpServletRequest, errors );
        return ( new ActionForward( actionMapping.getInput() ) );
      }

      // Prfen ob ein selektierte Teilnehmer aus der ArrayListe gelscht werden muss
      if ( teilnehmerForm.getSelectedOptions() != null )
      {
        try
        {
          participants = removeTN();
        }
        catch ( Exception ex )
        {
          LOG.debug( "Exception (removeTN):" + ex.getMessage() );
          errors.add( "addTN", new ActionError( "errors.removeError", ex.getMessage() ) );
          saveErrors( httpServletRequest, errors );
          return ( new ActionForward( actionMapping.getInput() ) );
        }
      }

      teilnehmerForm.reset( actionMapping, httpServletRequest );

      return ( actionMapping.findForward( "forward" ) );
    }
  }

  /**
   * Fgt einen Teilnehmer in die ArrayListe hinzu.
   * @throws Exception Unerwarteter Fehler
   */
  private void addTN() throws Exception
  {
    try
    {
      participantVO = fillParticipantVO( counter );
    }
    catch ( Exception ex )
    {
      throw new Exception( ex );
    }

    // Neuer Teilnehmer in ArrayListe einfgen.
    participants = delegate.addTN( participantVO );
  }

  /**
   * Diese Methode fllt das ParticipantVO ab.
   * @param index int
   * @throws Exception Unerwarteter Fehler
   * @return ParticipantVO Value-Object
   */
  private ParticipantVO fillParticipantVO( int index ) throws Exception
  {
    ParticipantVO participantVO = new ParticipantVO();

    participantVO.setIndex( index );
    participantVO.setFirstname( teilnehmerForm.getTxfVorname() );
    participantVO.setLastname( teilnehmerForm.getTxfName() );
    participantVO.setCountryCd( teilnehmerForm.getCbxLand() );
    participantVO.setCity( teilnehmerForm.getTxfOrt() );
    counter++;
    return participantVO;
  }

  /**
   * Diese Methode lscht einen Teilnehmer aus der ArrayListe
   */
  private ArrayList removeTN() throws Exception
  {
    int[] idRemove = teilnehmerForm.getSelectedOptions();
    for ( int i = idRemove.length - 1; i >= 0; i-- )
    {
      int id = idRemove[ i ];
      participants = delegate.removeTN( id );
    }
    // Counter aktualisieren
    if ( participants == null )
    {
      counter = 0;
    }
    else
    {
      counter = participants.size() + 1;
    }

    return participants;
  }
}
