package ch.sws.tasaf.client;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import org.apache.struts.action.*;
import org.apache.struts.util.MessageResources;
import ch.sws.tasaf.bo.vo.BookingVO;

/**
 * Die Klasse VorschauAction verarbeitet die Daten der VorschauForm.
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @see VorschauForm
 * @author    Anita Rueegsegger, Marc Bouquet
 * @version   1.0
 */
public class VorschauAction extends Action
{
  private static final Logger LOG = Logger.getLogger( VorschauAction.class );

  /**
   * Die Methode execute wird aufgerufen, wenn auf der JavaServerPage der Button "Jetzt Buchen" gedrckt wird.
   * Durch diese Methode werden die Reisedaten in der Datenbank gespeichert und die nchste Seite aufgerufen,
   * die im Client angezeigt wird.
   * In der Methode werden die Daten verarbeitet die in der Form gehalten werden.
   * @param actionMapping ActionMapping
   * @param actionForm ActionForm
   * @param httpServletRequest HttpServletRequest
   * @param httpServletResponse HttpServletResponse
   * @throws Exception
   * @return ActionForward
   */
  public ActionForward execute( ActionMapping actionMapping, ActionForm actionForm, HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse )
  {
    ActionErrors errors = new ActionErrors();
    HttpSession session = httpServletRequest.getSession();
    MessageResources messages = getResources( httpServletRequest );
    VorschauForm vorschauForm = ( VorschauForm ) actionForm;

    Delegate delegate = Delegate.getInstance();

    try
    {
      BookingVO bookingVO = delegate.getVorschau();
      delegate.saveVorschau( bookingVO );
    }
    catch ( Exception ex )
    {
      LOG.debug( "Message: " + ex.getMessage() );
      errors.add( "bookingVO", new ActionError( "errors.saveError", ex.getMessage() ) );
      saveErrors( httpServletRequest, errors );
      return ( new ActionForward( actionMapping.getInput() ) );
    }

    LOG.info("Session invalidate: " + session.getId());
    session.invalidate();

    return ( actionMapping.findForward( "forward" ) );
  }
}
