package ch.sws.tasaf.db;

import java.sql.*;
import java.util.ArrayList;
import org.apache.log4j.Logger;
import ch.sws.tasaf.bo.vo.AreaVO;

/**
 * Kapselung der DB-Zugriffe auf die Tabelle AREA
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @author Anita Rueegsegger, Marc Bouquet
 * @version 1.0
 */
public class AreaDAO
{
  private static final Logger LOG = Logger.getLogger( AreaDAO.class );

  /**
   * Standard Konstruktor
   */
  public AreaDAO()
  {
  }

  /**
   * Selektiert alle Areas mit den entsprechenden Destinations
   * @return ArrayList AreaVO - Areas mit den entsprechenden Destinations (Menu im Browser)
   */
  public ArrayList select() throws Exception
  {
    ArrayList alAreaVO = this.selectAreas();
    for ( int i = 0; i < alAreaVO.size(); i++ )
    {
      AreaVO areaVO = ( AreaVO ) alAreaVO.get( i );
      ArrayList alDestinationVO = new DestinationDAO().selectDestinations( areaVO.getIdArea() );
      areaVO.setAlDestinationVO( alDestinationVO );
    }

    return alAreaVO;
  }

  /**
   * Selektiert alle Areas aus der Tabelle AREA
   * @return ArrayList AreaVO
   */
  public ArrayList selectAreas() throws SQLException
  {
    Connection con = null;
    PreparedStatement ps = null;
    ResultSet rs = null;
    String query = null;
    ArrayList alAreaVO = new ArrayList();

    try
    {
      query = "SELECT idArea, area FROM area";

      con = DBHelper.getInstance().getConnection( DBHelper.MYSQL, DBHelper.JDBC_MYSQL );
      ps = con.prepareStatement( query );
      rs = ps.executeQuery();

      while ( rs.next() )
      {
        AreaVO vo = new AreaVO();
        vo.setIdArea( rs.getInt( "idArea" ) );
        vo.setArea( rs.getString( "area" ) );
        alAreaVO.add( vo );
      }
    }
    catch ( SQLException sqlex )
    {
      LOG.debug( "AreaDAO.selectAreas(): " + sqlex.getMessage() );
      throw new SQLException( "AreaDAO.selectAreas(): " + sqlex.getMessage() );
    }
    finally
    {
      DBHelper.getInstance().close( con, ps );
    }

    return alAreaVO;
  }
}
