package ch.sws.tasaf.db;

import java.sql.*;
import java.util.ArrayList;
import org.apache.log4j.Logger;
import ch.sws.tasaf.bo.vo.DestinationVO;
import ch.sws.tasaf.bo.vo.HotelVO;

/**
 * Kapselung der DB-Zugriffe auf die Tabelle DESTINATION
 * <p>
 * Copyright (c) 2004, Eidgenssisches Institut fr Geistiges Eigentum
 * @author Anita Rueegsegger, Marc Bouquet
 * @version 1.0
 */
public class DestinationDAO
{
  private static final Logger LOG = Logger.getLogger( DestinationDAO.class );

  /**
   * Standard Konstruktor
   */
  public DestinationDAO()
  {
  }

  /**
   *
   * @param idDestinatio int
   * @return DestinationVO
   */
  public DestinationVO select( int idDestinatio ) throws Exception
  {
    DestinationVO vo = this.selectDestination( idDestinatio );
    vo.setAlHotelVO( selectHotels( idDestinatio ) );
    return vo;
  }

  /**
   * Selektiert Daten einer Destination aus der Tabelle Destination
   * @param idDestination int gesuchte Destination
   * @return DestinationVO der entsprechenden Destionation
   */
  public DestinationVO selectDestination( int idDestination ) throws SQLException
  {
    Connection con = null;
    PreparedStatement ps = null;
    ResultSet rs = null;
    String query = null;
    DestinationVO vo = new DestinationVO();

    try
    {
      query = "SELECT idDestination, idArea, destination, description " +
              "FROM destination " +
              "WHERE idDestination = ?";

      con = DBHelper.getInstance().getConnection( DBHelper.MYSQL, DBHelper.JDBC_MYSQL );
      ps = con.prepareStatement( query );
      ps.setInt( 1, idDestination );
      rs = ps.executeQuery();

      if ( rs.next() )
      {
        vo.setIdDestination( rs.getInt( "idDestination" ) );
        vo.setIdArea( rs.getInt( "idArea" ) );
        vo.setDestination( rs.getString( "destination" ) );
        vo.setDescription( rs.getString( "description" ) );
      }
    }
    catch ( SQLException sqlex )
    {
      LOG.debug( "DestinationDAO.selectDestination(): " + sqlex.getMessage() );
      throw new SQLException( "DestinationDAO.selectDestination(): " + sqlex.getMessage() );
    }
    finally
    {
      DBHelper.getInstance().close( con, ps );
    }

    return vo;
  }

  /**
   * Selektiert die Hotels einer Destination aus der Tabelle Hotel
   * @param idDestination int Destination von der Hotels verlangt werden
   * @throws SQLException
   * @return ArrayList HotelVO der entprechenden Destination
   */
  public ArrayList selectHotels( int idDestination ) throws SQLException
  {
    Connection con = null;
    PreparedStatement ps = null;
    ResultSet rs = null;
    String query = null;
    ArrayList alHotelVO = new ArrayList();

    try
    {
      query = "SELECT idHotel, idDestination, name, description, category, priceDoubleRoom, priceSingleRoom " +
              "FROM hotel " +
              "WHERE idDestination = ?";

      con = DBHelper.getInstance().getConnection( DBHelper.MYSQL, DBHelper.JDBC_MYSQL );
      ps = con.prepareStatement( query );
      ps.setInt( 1, idDestination );
      rs = ps.executeQuery();

      while ( rs.next() )
      {
        HotelVO vo = new HotelVO();
        vo.setIdHotel( rs.getInt( "idHotel" ) );
        vo.setIdDestination( rs.getInt( "idDestination" ) );
        vo.setName( rs.getString( "name" ) );
        vo.setDescription( rs.getString( "description" ) );
        vo.setCategory( rs.getInt( "category" ) );
        vo.setPriceDoubleRoom( rs.getFloat( "priceDoubleRoom" ) );
        vo.setPriceSingleRoom( rs.getFloat( "priceSingleRoom" ) );
        alHotelVO.add( vo );
      }
    }
    catch ( SQLException sqlex )
    {
      LOG.debug( "DestinationDAO.selectHotels(): " + sqlex.getMessage() );
      throw new SQLException( "DestinationDAO.selectHotels(): " + sqlex.getMessage() );
    }
    finally
    {
      DBHelper.getInstance().close( con, ps );
    }

    return alHotelVO;
  }

  /**
   * Selektiert Destination-Daten einer entsprechenden Area
   * @param idArea int Area von der Destinations gesucht werden
   * @return ArrayList DestinationVO der entsprechenden Area
   */
  public ArrayList selectDestinations( int idArea ) throws SQLException
  {
    Connection con = null;
    PreparedStatement ps = null;
    ResultSet rs = null;
    String query = null;
    ArrayList arrayList = new ArrayList();

    try
    {
      query = "SELECT idDestination, destination FROM destination WHERE idArea = ?";

      con = DBHelper.getInstance().getConnection( DBHelper.MYSQL, DBHelper.JDBC_MYSQL );
      ps = con.prepareStatement( query );
      ps.setInt( 1, idArea );
      rs = ps.executeQuery();

      while ( rs.next() )
      {
        DestinationVO vo = new DestinationVO();
        vo.setIdDestination( rs.getInt( "idDestination" ) );
        vo.setDestination( rs.getString( "destination" ) );
        arrayList.add( vo );
      }
    }
    catch ( SQLException sqlex )
    {
      LOG.debug( "DestinationDAO.selectDestinations(): " + sqlex.getMessage() );
      throw new SQLException( "DestinationDAO.selectDestinations(): " + sqlex.getMessage() );
    }
    finally
    {
      DBHelper.getInstance().close( con, ps );
    }

    return arrayList;
  }
}
